@@ -221,13 +221,37 @@ class VariableOsDeviceMap(ReadonlyVariable):
                    enumerate(self.Get('os_device_dev')))
 
 
+class VariableOsDeviceArraySet(ReadonlyVariable):
+    """
+    Диски массивы (при создании разделов на таких дисках перед
+    номером раздела добавляется "p": nvme0n1p1 вместо nvme0n11
+    """
+    type = "list"
+    devnames = ("nvme",)
+
+    def get(self):
+        """Get device partition table"""
+
+        def isArray(device, name):
+            if any(x in device for x in self.devnames):
+                return "on"
+            else:
+                return "off"
+
+        return map(lambda x: isArray(*x),
+                   zip(self.Get('os_device_dev'),
+                       self.Get('os_device_name')))
+
+
 class VariableOsDeviceSsdSet(ReadonlyVariable):
     """
-    Table on device
+    Ssd property
     """
     type = "list"
     ssd_names = ("SSD", "OCZ", "PLEXTOR")
     udev_property = 'ID_ATA_ROTATION_RATE_RPM'
+    # считаем, что nvme диски - SSD
+    devnames = ("nvme",)
 
     def get(self):
         """Get device partition table"""
@@ -235,7 +259,8 @@ class VariableOsDeviceSsdSet(ReadonlyVariable):
         def isSsd(device, name):
             prop = getUdevDeviceInfo(name=device)
             rpm = prop.get(self.udev_property, None)
-            if rpm == "0" or any(x in name for x in self.ssd_names):
+            if (any(x in device for x in self.devnames) 
+                or rpm == "0" or any(x in name for x in self.ssd_names)):
                 return "on"
             else:
                 return "off"
@@ -346,9 +371,14 @@ class VariableOsDeviceName(ReadonlyVariable):
                 devicepath = pathJoin("/sys", devicepath)
             pathVendor = "%s/device/vendor" % devicepath
             pathModel = "%s/device/model" % devicepath
-            return ("%s %s" %
-                    (readFile(pathVendor).strip(),
-                     readFile(pathModel).strip())).strip()
+            vendor = readFile(pathVendor).strip()
+            model = readFile(pathModel).strip()
+            if vendor or model:
+                return ("%s %s" %
+                        (vendor, model)).strip()
+            elif "nvme" in devicepath:
+                return "NVME"
+            return ""
         else:
             return ""
 
